@@ -29,6 +29,7 @@ STATUS_RUNNING           = 'running'
 STATUS_SUCCESS           = 'success'
 STATUS_FINISHED          = 'finished'
 STATUS_EXECUTION_ERROR   = 'execution_error'
+STATUS_COMPILATION_ERROR = 'compilation_error'
 STATUS_SERVICE_ERROR     = 'service_error'
 STATUS_STOPPING          = 'stopping'
 STATUS_STOPPED           = 'stopped'
@@ -39,6 +40,7 @@ COMPLETE_STATUSES = (
     STATUS_PLAN_ERROR,
     STATUS_SUCCESS,
     STATUS_EXECUTION_ERROR,
+    STATUS_COMPILATION_ERROR,
     STATUS_SERVICE_ERROR,
     STATUS_STOPPED,
     STATUS_FINISHED)
